@@ -76,6 +76,8 @@ from jwt import decode
 
 from invenio_oauthclient.errors import OAuthCERNRejectedAccountError
 from invenio_oauthclient.handlers.rest import response_handler
+from invenio_oauthclient.handlers.utils import \
+    require_more_than_one_external_account
 from invenio_oauthclient.models import RemoteAccount
 from invenio_oauthclient.proxies import current_oauthclient
 from invenio_oauthclient.utils import oauth_link_external_id, \
@@ -262,6 +264,7 @@ def get_resource(remote, token_response=None):
 
 def _account_info(remote, resp):
     """Retrieve remote account information used to find local user."""
+    g.oauth_logged_in_with_remote = remote
     resource = get_resource(remote, resp)
 
     valid_roles = current_app.config.get(
@@ -320,6 +323,7 @@ def account_info_rest(remote, resp):
         )
 
 
+@require_more_than_one_external_account
 def _disconnect(remote, *args, **kwargs):
     """Handle unlinking of remote account."""
     if not current_user.is_authenticated:
@@ -385,6 +389,11 @@ def on_identity_changed(sender, identity):
         disconnect_identity(identity)
         return
 
+    remote = g.get("oauth_logged_in_with_remote", None)
+    if not remote or remote.name != "cern_openid":
+        # signal coming from another remote app
+        return
+
     logged_in_via_token = hasattr(current_user, 'login_via_oauth2') \
         and getattr(current_user, 'login_via_oauth2')
 
@@ -402,7 +411,6 @@ def on_identity_changed(sender, identity):
             OAUTHCLIENT_CERN_OPENID_REFRESH_TIMEDELTA,
         )
         if refresh:
-            remote = find_remote_by_client_id(client_id)
             resource = get_resource(remote)
             roles.extend(
                 account_roles_and_extra_data(
