@@ -9,8 +9,6 @@
 
 """Pytest configuration."""
 
-from __future__ import absolute_import, print_function
-
 import json
 import os
 import shutil
@@ -46,6 +44,7 @@ from invenio_oauthclient.contrib.keycloak import KeycloakSettingsHelper
 from invenio_oauthclient.contrib.orcid import REMOTE_APP as ORCID_REMOTE_APP
 from invenio_oauthclient.contrib.orcid import \
     REMOTE_REST_APP as ORCID_REMOTE_REST_APP
+from invenio_oauthclient.utils import _create_registrationform
 from invenio_oauthclient.views.client import blueprint as blueprint_client
 from invenio_oauthclient.views.client import rest_blueprint
 from invenio_oauthclient.views.settings import blueprint as blueprint_settings
@@ -67,16 +66,19 @@ def base_app(request):
     # allow HTTP for keycloak tests, and create the KEYCLOAK_REMOTE_APP
     os.environ["OAUTHLIB_INSECURE_TRANSPORT"] = "1"
     base_url, realm = "http://localhost:8080", "test"
-    helper = KeycloakSettingsHelper(base_url=base_url, realm=realm)
-    KEYCLOAK_REMOTE_APP = helper.remote_app()
+    helper = KeycloakSettingsHelper(title="Keycloak", description="",
+                                    base_url=base_url, realm=realm)
+    KEYCLOAK_REMOTE_APP = helper.remote_app
 
     instance_path = tempfile.mkdtemp()
     base_app = Flask('testapp')
     base_app.config.update(
+        ACCOUNTS_LOCAL_LOGIN_ENABLED=True,
         TESTING=True,
         WTF_CSRF_ENABLED=False,
         LOGIN_DISABLED=False,
         CACHE_TYPE='simple',
+        OAUTHCLIENT_SIGNUP_FORM=_create_registrationform,
         OAUTHCLIENT_REMOTE_APPS=dict(
             cern=CERN_REMOTE_APP,
             cern_openid=CERN_OPENID_REMOTE_APP,
